import 'package:flutter/material.dart';
import 'dart:async';

import 'package:flutter/services.dart';
import 'package:mobkit/mobkit.dart';

void main() => runApp(MyApp());

class MyApp extends StatefulWidget {
  @override
  _MyAppState createState() => _MyAppState();
}

class _MyAppState extends State<MyApp> {
  String _platformVersion = 'Unknown';
  String _deviceModel = 'Unknown';
  String _duid = '';

  @override
  void initState() {
    super.initState();
    initPlatformState();
  }

  // Platform messages are asynchronous, so we initialize in an async method.
  Future<void> initPlatformState() async {
    String platformVersion;
    String deviceModel;
    String duid;
    // Platform messages may fail, so we use a try/catch PlatformException.
    try {
      platformVersion = await Mobkit.platformVersion;
    } on PlatformException {
      platformVersion = 'Failed to get platform version.';
    }

    try {
      deviceModel = await Mobkit.deviceModel;
    } on PlatformException {
      deviceModel = 'Failed to get deviceModel.';
    }

    try {
      duid = await Mobkit.getDuid;
    } on PlatformException {
      duid = 'Failed to get duid.';
    }

    // If the widget was removed from the tree while the asynchronous platform
    // message was in flight, we want to discard the reply rather than calling
    // setState to update our non-existent appearance.
    if (!mounted) return;

    setState(() {
      _platformVersion = platformVersion;
      _deviceModel = deviceModel;
      _duid = duid;
    });
  }

  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      home: Scaffold(
        appBar: AppBar(
          title: const Text('Plugin example app'),
        ),
        body: Center(
          child: Text('Running on: $_deviceModel $_platformVersion\nduid:$_duid\n'),
        ),
      ),
    );
  }
}
